@@ -36,6 +36,7 @@ __all__ = (
     "ConnectorProfileCredentialsTypeDef",
     "ConnectorProfilePropertiesTypeDef",
     "ConnectorProfileTypeDef",
+    "CustomerProfilesDestinationPropertiesTypeDef",
     "DatadogConnectorProfileCredentialsTypeDef",
     "DatadogConnectorProfilePropertiesTypeDef",
     "DatadogSourcePropertiesTypeDef",
@@ -56,6 +57,9 @@ __all__ = (
     "GoogleAnalyticsConnectorProfileCredentialsTypeDef",
     "GoogleAnalyticsMetadataTypeDef",
     "GoogleAnalyticsSourcePropertiesTypeDef",
+    "HoneycodeConnectorProfileCredentialsTypeDef",
+    "HoneycodeDestinationPropertiesTypeDef",
+    "HoneycodeMetadataTypeDef",
     "IncrementalPullConfigTypeDef",
     "InforNexusConnectorProfileCredentialsTypeDef",
     "InforNexusConnectorProfilePropertiesTypeDef",
@@ -158,7 +162,10 @@ ConnectorConfigurationTypeDef = TypedDict(
                 "Amplitude",
                 "Veeva",
                 "EventBridge",
+                "LookoutMetrics",
                 "Upsolver",
+                "Honeycode",
+                "CustomerProfiles",
             ]
         ],
         "supportedSchedulingFrequencies": List[
@@ -225,6 +232,8 @@ ConnectorMetadataTypeDef = TypedDict(
         "Zendesk": "ZendeskMetadataTypeDef",
         "EventBridge": Dict[str, Any],
         "Upsolver": Dict[str, Any],
+        "CustomerProfiles": Dict[str, Any],
+        "Honeycode": "HoneycodeMetadataTypeDef",
     },
     total=False,
 )
@@ -478,6 +487,7 @@ ConnectorProfileCredentialsTypeDef = TypedDict(
         "Datadog": "DatadogConnectorProfileCredentialsTypeDef",
         "Dynatrace": "DynatraceConnectorProfileCredentialsTypeDef",
         "GoogleAnalytics": "GoogleAnalyticsConnectorProfileCredentialsTypeDef",
+        "Honeycode": "HoneycodeConnectorProfileCredentialsTypeDef",
         "InforNexus": "InforNexusConnectorProfileCredentialsTypeDef",
         "Marketo": "MarketoConnectorProfileCredentialsTypeDef",
         "Redshift": "RedshiftConnectorProfileCredentialsTypeDef",
@@ -500,6 +510,7 @@ ConnectorProfilePropertiesTypeDef = TypedDict(
         "Datadog": "DatadogConnectorProfilePropertiesTypeDef",
         "Dynatrace": "DynatraceConnectorProfilePropertiesTypeDef",
         "GoogleAnalytics": Dict[str, Any],
+        "Honeycode": Dict[str, Any],
         "InforNexus": "InforNexusConnectorProfilePropertiesTypeDef",
         "Marketo": "MarketoConnectorProfilePropertiesTypeDef",
         "Redshift": "RedshiftConnectorProfilePropertiesTypeDef",
@@ -538,7 +549,10 @@ ConnectorProfileTypeDef = TypedDict(
             "Amplitude",
             "Veeva",
             "EventBridge",
+            "LookoutMetrics",
             "Upsolver",
+            "Honeycode",
+            "CustomerProfiles",
         ],
         "connectionMode": Literal["Public", "Private"],
         "credentialsArn": str,
@@ -549,6 +563,21 @@ ConnectorProfileTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredCustomerProfilesDestinationPropertiesTypeDef = TypedDict(
+    "_RequiredCustomerProfilesDestinationPropertiesTypeDef", {"domainName": str}
+)
+_OptionalCustomerProfilesDestinationPropertiesTypeDef = TypedDict(
+    "_OptionalCustomerProfilesDestinationPropertiesTypeDef", {"objectTypeName": str}, total=False
+)
+
+
+class CustomerProfilesDestinationPropertiesTypeDef(
+    _RequiredCustomerProfilesDestinationPropertiesTypeDef,
+    _OptionalCustomerProfilesDestinationPropertiesTypeDef,
+):
+    pass
+
+
 DatadogConnectorProfileCredentialsTypeDef = TypedDict(
     "DatadogConnectorProfileCredentialsTypeDef", {"apiKey": str, "applicationKey": str}
 )
@@ -567,7 +596,10 @@ DestinationConnectorPropertiesTypeDef = TypedDict(
         "Salesforce": "SalesforceDestinationPropertiesTypeDef",
         "Snowflake": "SnowflakeDestinationPropertiesTypeDef",
         "EventBridge": "EventBridgeDestinationPropertiesTypeDef",
+        "LookoutMetrics": Dict[str, Any],
         "Upsolver": "UpsolverDestinationPropertiesTypeDef",
+        "Honeycode": "HoneycodeDestinationPropertiesTypeDef",
+        "CustomerProfiles": "CustomerProfilesDestinationPropertiesTypeDef",
     },
     total=False,
 )
@@ -605,7 +637,10 @@ _RequiredDestinationFlowConfigTypeDef = TypedDict(
             "Amplitude",
             "Veeva",
             "EventBridge",
+            "LookoutMetrics",
             "Upsolver",
+            "Honeycode",
+            "CustomerProfiles",
         ],
         "destinationConnectorProperties": "DestinationConnectorPropertiesTypeDef",
     },
@@ -758,7 +793,10 @@ FlowDefinitionTypeDef = TypedDict(
             "Amplitude",
             "Veeva",
             "EventBridge",
+            "LookoutMetrics",
             "Upsolver",
+            "Honeycode",
+            "CustomerProfiles",
         ],
         "destinationConnectorType": Literal[
             "Salesforce",
@@ -778,7 +816,10 @@ FlowDefinitionTypeDef = TypedDict(
             "Amplitude",
             "Veeva",
             "EventBridge",
+            "LookoutMetrics",
             "Upsolver",
+            "Honeycode",
+            "CustomerProfiles",
         ],
         "triggerType": Literal["Scheduled", "Event", "OnDemand"],
         "createdAt": datetime,
@@ -817,6 +858,32 @@ GoogleAnalyticsSourcePropertiesTypeDef = TypedDict(
     "GoogleAnalyticsSourcePropertiesTypeDef", {"object": str}
 )
 
+HoneycodeConnectorProfileCredentialsTypeDef = TypedDict(
+    "HoneycodeConnectorProfileCredentialsTypeDef",
+    {"accessToken": str, "refreshToken": str, "oAuthRequest": "ConnectorOAuthRequestTypeDef"},
+    total=False,
+)
+
+_RequiredHoneycodeDestinationPropertiesTypeDef = TypedDict(
+    "_RequiredHoneycodeDestinationPropertiesTypeDef", {"object": str}
+)
+_OptionalHoneycodeDestinationPropertiesTypeDef = TypedDict(
+    "_OptionalHoneycodeDestinationPropertiesTypeDef",
+    {"errorHandlingConfig": "ErrorHandlingConfigTypeDef"},
+    total=False,
+)
+
+
+class HoneycodeDestinationPropertiesTypeDef(
+    _RequiredHoneycodeDestinationPropertiesTypeDef, _OptionalHoneycodeDestinationPropertiesTypeDef
+):
+    pass
+
+
+HoneycodeMetadataTypeDef = TypedDict(
+    "HoneycodeMetadataTypeDef", {"oAuthScopes": List[str]}, total=False
+)
+
 IncrementalPullConfigTypeDef = TypedDict(
     "IncrementalPullConfigTypeDef", {"datetimeTypeFieldName": str}, total=False
 )
@@ -1008,6 +1075,7 @@ _OptionalScheduledTriggerPropertiesTypeDef = TypedDict(
         "scheduleEndTime": datetime,
         "timezone": str,
         "scheduleOffset": int,
+        "firstExecutionFrom": datetime,
     },
     total=False,
 )
@@ -1148,7 +1216,10 @@ _RequiredSourceFlowConfigTypeDef = TypedDict(
             "Amplitude",
             "Veeva",
             "EventBridge",
+            "LookoutMetrics",
             "Upsolver",
+            "Honeycode",
+            "CustomerProfiles",
         ],
         "sourceConnectorProperties": "SourceConnectorPropertiesTypeDef",
     },
@@ -1355,7 +1426,10 @@ DescribeConnectorsResponseTypeDef = TypedDict(
                 "Amplitude",
                 "Veeva",
                 "EventBridge",
+                "LookoutMetrics",
                 "Upsolver",
+                "Honeycode",
+                "CustomerProfiles",
             ],
             "ConnectorConfigurationTypeDef",
         ],
